@@ -396,6 +396,12 @@ do_sync (gpointer *user_data)
 	}
 	pulse_bar(bar);
 
+	g_printerr("###### Got User from server ########\n");
+	g_printerr("# First name: %s\n", user->first_name);
+	g_printerr("# Last name: %s\n", user->last_name);
+	g_printerr("#   Api ref: %s\n", user->api_ref);
+	g_printerr("####################################\n");
+
 	/* Create list of all local notes */
 	/* Just copy NoteStore to normal list */
 	ConboyNoteStore *note_store = app_data->note_store;
