@@ -30,12 +30,13 @@
 #include <string.h>
 
 #include "app_data.h"
-#include "search_window.h"
 #include "metadata.h"
 #include "note.h"
 #include "conboy_note_store.h"
 #include "settings.h"
 #include "search.h"
+#include "ui_helper.h"
+#include "search_window.h"
 
 typedef struct {
 	GtkWidget          *search_field;
@@ -159,7 +160,6 @@ static
 gboolean on_hardware_key_pressed(GtkWidget *widget, GdkEventKey	*event, gpointer user_data)
 {
 	GtkWidget *window = GTK_WIDGET(user_data);
-	AppData *app_data = app_data_get();
 
 	switch (event->keyval) {
 
@@ -167,40 +167,9 @@ gboolean on_hardware_key_pressed(GtkWidget *widget, GdkEventKey	*event, gpointer
 		gtk_widget_hide(window);
 		return TRUE;
 
-	/* TODO: Duplicated code The same code (only last line differs) is used in callbacks.c */
 	case HILDON_HARDKEY_FULLSCREEN:
 		/* Toggle fullscreen */
-		app_data->fullscreen = !app_data->fullscreen;
-
-		/* Set all open windows to fullscreen or unfullscreen */
-		if (app_data->fullscreen) {
-			gtk_window_fullscreen(GTK_WINDOW(app_data->note_window->window));
-		} else {
-			gtk_window_unfullscreen(GTK_WINDOW(app_data->note_window->window));
-		}
-		/*
-		open_windows = app_data->open_windows;
-		while (open_windows != NULL) {
-			UserInterface *open_window = (UserInterface*)open_windows->data;
-			if (app_data->fullscreen) {
-				gtk_window_fullscreen(GTK_WINDOW(open_window->window));
-			} else {
-				gtk_window_unfullscreen(GTK_WINDOW(open_window->window));
-			}
-			open_windows = open_windows->next;
-		}
-		*/
-		/* Set search window to fullscreen or unfullscreen */
-		if (app_data->search_window != NULL) {
-			if (app_data->fullscreen) {
-				gtk_window_fullscreen(GTK_WINDOW(app_data->search_window));
-			} else {
-				gtk_window_unfullscreen(GTK_WINDOW(app_data->search_window));
-			}
-		}
-
-		/* Focus again this window */
-		gtk_window_present(GTK_WINDOW(window));
+		ui_helper_toggle_fullscreen(GTK_WINDOW(window));
 		return TRUE;
 	}
 
@@ -289,6 +258,12 @@ on_new_note_action_activated(GtkAction *action, gpointer user_data)
 }
 */
 
+static void
+on_fullscreen_button_clicked (GtkAction *action, gpointer user_data)
+{
+	ui_helper_toggle_fullscreen(GTK_WINDOW(user_data));
+}
+
 static
 gint compare_titles(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data)
 {
@@ -362,17 +337,28 @@ HildonWindow* search_window_create(SearchWindowData *window_data)
 	GdkScreen *screen;
 	GHashTable *search_result;
 	GtkAction *new_note_action;
+	GtkAction *fullscreen_action;
 	GtkWidget *menu_new_note;
 #ifdef HILDON_HAS_APP_MENU
 	win = hildon_stackable_window_new();
 #else
 	win = hildon_window_new();
 #endif
-	gtk_window_set_title(GTK_WINDOW(win), _("Search All Notes"));
+	gtk_window_set_title(GTK_WINDOW(win), _("Search all notes"));
 	screen = gdk_screen_get_default();
 	search_result = g_hash_table_new(NULL, NULL);
 
-	/*new_note_action = GTK_ACTION(gtk_action_new("new", _("New Note"), NULL, NULL));*/
+	GtkAccelGroup *accel_group = gtk_accel_group_new();
+	gtk_window_add_accel_group(GTK_WINDOW(win), accel_group);
+	g_object_unref(accel_group);
+
+	GtkActionGroup *action_group = gtk_action_group_new("searchwin");
+	fullscreen_action = GTK_ACTION(gtk_action_new("fullscreen", _("Fullscreen"), NULL, NULL));
+
+	gtk_action_group_add_action_with_accel(action_group, fullscreen_action, "<Ctrl>u");
+	gtk_action_set_accel_group(fullscreen_action, accel_group);
+	gtk_action_connect_accelerator(fullscreen_action);
+
 
 	/* Window menu */
 #ifdef HILDON_HAS_APP_MENU
@@ -386,8 +372,8 @@ HildonWindow* search_window_create(SearchWindowData *window_data)
 	*/
 
 	/* Add sort filters */
-	button_sort_by_title = gtk_radio_button_new_with_label(NULL, _("Sort By Title"));
-	button_sort_by_date = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(button_sort_by_title), _("Sort By Date"));
+	button_sort_by_title = gtk_radio_button_new_with_label(NULL, _("Sort by title"));
+	button_sort_by_date = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(button_sort_by_title), _("Sort by date"));
 
 	/* Draw them as toggle buttons, not as radio buttons */
 	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(button_sort_by_title), FALSE);
@@ -511,7 +497,7 @@ HildonWindow* search_window_create(SearchWindowData *window_data)
 
 	/* CHANGE_DATE COLUMN */
 	renderer = gtk_cell_renderer_text_new();
-	change_date_column = gtk_tree_view_column_new_with_attributes(_("Last Changed"), renderer, "text", CHANGE_DATE_COLUMN, NULL);
+	change_date_column = gtk_tree_view_column_new_with_attributes(_("Last changed"), renderer, "text", CHANGE_DATE_COLUMN, NULL);
 	gtk_tree_view_column_set_sort_column_id(change_date_column, CHANGE_DATE_COLUMN);
 	gtk_tree_view_column_set_sort_indicator(change_date_column, TRUE);
 	gtk_tree_view_column_set_reorderable(change_date_column, FALSE);
@@ -540,17 +526,17 @@ HildonWindow* search_window_create(SearchWindowData *window_data)
 	g_signal_connect(tree, "key_press_event", G_CALLBACK(on_key_pressed), search_field);
 	g_signal_connect(screen, "size-changed", G_CALLBACK(on_orientation_changed), window_data);
 	/*g_signal_connect(new_note_action, "activate", G_CALLBACK(on_new_note_action_activated), win);*/
+	g_signal_connect(fullscreen_action, "activate", G_CALLBACK(on_fullscreen_button_clicked), win);
 
 	gconf_client_notify_add(app_data->client, SETTINGS_SCROLLBAR_SIZE, on_scrollbar_settings_changed, scrolledwindow, NULL, NULL);
 
 #ifdef HILDON_HAS_APP_MENU
 	g_signal_connect(button_sort_by_title, "toggled", G_CALLBACK(on_sort_by_title_changed), sorted_store);
 	g_signal_connect(button_sort_by_date, "toggled", G_CALLBACK(on_sort_by_date_changed), sorted_store);
+	/* Add transparent fullscreen button */
+	fullscreen_manager_new(GTK_WINDOW(win), ui_helper_toggle_fullscreen);
 #endif
 
-	app_data = app_data_get();
-	app_data->note_store = store;
-
 	return HILDON_WINDOW(win);
 }
 
